<table>
  <tr>
    <th>Name</th>
    <th>Value</th>
  </tr>
  {% for row in table %}
  <tr>
    <td><code>{{ row.name }}</code></td>
    <td><code>{{ row.value }}</code></td>
  </tr>
  {% endfor %}
</table>
