<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>ASGI + HTMX</title>
</head>
<body>
  <h1>ASGI + HTMX</h1>

  {{ render_partial('partials/clickme.html', request=request) }}

  {% if framework == "quart" %}
    <script src="{{ url_for('static', filename="/js/htmx.min.js") }}" defer></script>
  {% else %}
    <script src="{{ url_for('static', path="/js/htmx.min.js") }}" defer></script>
  {% endif %}
</body>
</html>
